inputHintText property
Hint text shown inside the input field when it is empty.
Ignored when inputDecoration is provided.
Defaults to 'Answer the question'.
Implementation
final String? inputHintText;
Hint text shown inside the input field when it is empty.
Ignored when inputDecoration is provided.
Defaults to 'Answer the question'.
final String? inputHintText;