lockInput property
When true (e.g. multiple-choice step), the field stays visible but is not editable and send is off.
Implementation
final bool lockInput;
When true (e.g. multiple-choice step), the field stays visible but is not editable and send is off.
final bool lockInput;