ChatLayout class

Inheritance

Constructors

ChatLayout({Key? key, Widget? sendIcon, FormlessTheme? theme, void onComplete(Map<String, dynamic> data)?, void onError(String error)?, required AiProvider provider, required String apiKey, String? model, List<QuestionsModel> questions = kDefaultFormlessQuestions, String? unexpectedErrorMessage = 'Something went wrong, please try again.', FormlessOptionsSheetPresenter? optionsSheetPresenter})
const

Properties

apiKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
model → String?
final
onComplete → void Function(Map<String, dynamic> data)?
final
onError → void Function(String error)?
final
optionsSheetPresenter → FormlessOptionsSheetPresenter?
When set, used to open the multiple-choice sheet UI (long option lists). Defaults to the built-in searchable bottom sheet. Call FormlessOptionsSheetArgs.select when the user picks a value.
final
provider → AiProvider
final
questions → List<QuestionsModel>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendIcon → Widget?
final
theme → FormlessTheme?
final
unexpectedErrorMessage → String?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ChatLayout>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited