ChatMessageList class

Inheritance

Constructors

ChatMessageList({Key? key, required List messages, required ScrollController scrollController, required bool isWaiting, FormlessTheme? theme, void onEditMessage(int index)?, bool showOptionChips = false, bool optionPickerUsesSearchSheet = false, List<String>? optionChoices, String? optionsSheetTitle, String? optionsQuestionKey, FormlessOptionsSheetPresenter? optionsSheetPresenter, ValueChanged<String>? onOptionSelected, Widget? optionPickerIcon})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isWaiting bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
messages List
final
onEditMessage → void Function(int index)?
final
onOptionSelected ValueChanged<String>?
final
optionChoices List<String>?
final
optionPickerIcon Widget?
Icon to show in the option picker button.
final
optionPickerUsesSearchSheet bool
When true with showOptionChips, opens a searchable sheet instead of chips.
final
optionsQuestionKey String?
QuestionsModel.key for the current options step (for custom sheets).
final
optionsSheetPresenter FormlessOptionsSheetPresenter?
When non-null, used instead of showDefaultFormlessOptionPickerSheet for the searchable-sheet option step.
final
optionsSheetTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
final
showOptionChips bool
When true, shows centered choice chips as the last list row (below the question).
final
theme FormlessTheme?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited