showOptionChips property
When true, shows centered choice chips as the last list row (below the question).
Implementation
final bool showOptionChips;
When true, shows centered choice chips as the last list row (below the question).
final bool showOptionChips;