QuestionOptionsPresentation enum
How multiple-choice QuestionsModel.options are shown in the chat.
Values
- automatic → const QuestionOptionsPresentation
-
Inline chips when the list is short (
QuestionsModel.optionsChipMaxCount); searchable sheet when the list is longer. Default whenoptionsPresentationon the question is null. - chips → const QuestionOptionsPresentation
-
Always inline chips (only for short lists — avoid for hundreds of items).
- searchableSheet → const QuestionOptionsPresentation
-
Always open a searchable list (e.g. countries, long enums).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QuestionOptionsPresentation> - A constant List of the values in this enum, in order of their declaration.