QuestionsModel class

Constructors

QuestionsModel({required String question, required String key, String? validationMessage, QuestionFieldType? type, Future<String?> onValidate(String answer)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The key to store the answer in the data map.
final
onValidate Future<String?> Function(String answer)?
Optional async callback for custom validation after the AI accepts the answer.
final
question String
The question to ask the user.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type QuestionFieldType?
Optional hint for how to interpret answers (text vs numeric, etc.).
final
validationMessage String?
Custom instructions for the AI on how to judge this answer (injected into the system prompt).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited